@@ -26,15 +26,15 @@ class Phase(str, _Enum):
 
 class LogKey(str, _Enum):
     TRAIN_LOG = 'train_log'
-    SERIALIZABLE_TRAIN = 'serializable_training_log'
+    SERIALIZABLE_TRAIN = 'serializable_train_scores'
 
     VALIDATION_LOG = 'validation_log'
     VALIDATION_METRICS = "validation_metrics"
-    SERIALIZABLE_VALIDATION = 'serializable_validation_log'
+    SERIALIZABLE_VALIDATION = 'serializable_validation_scores'
 
     TEST_METRICS = 'test_metrics'
-    SERIALIZABLE_TEST = 'serializable_test_log'
+    SERIALIZABLE_TEST = 'serializable_test_scores'
 
     GLOBAL_TEST_LOG = 'global_test_log'
     GLOBAL_TEST_METRICS = 'global_test_metrics'
-    SERIALIZABLE_GLOBAL_TEST = 'serializable_global_test_log'
+    SERIALIZABLE_GLOBAL_TEST = 'serializable_global_test_scores'
